#
# spec file for package python-HTTPolice
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-HTTPolice
Version:        0.9.0
Release:        5.1
Summary:        Validator for HTTP
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/vfaronov/httpolice
Source:         https://files.pythonhosted.org/packages/source/H/HTTPolice/HTTPolice-%{version}.tar.gz
BuildRequires:  %{python_module Brotli >= 1.0.1}
BuildRequires:  %{python_module bitstring >= 3.1.4}
BuildRequires:  %{python_module defusedxml >= 0.5.0}
BuildRequires:  %{python_module dominate >= 2.2.0}
BuildRequires:  %{python_module lxml >= 4.1.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-Brotli >= 1.0.1
Requires:       python-bitstring >= 3.1.4
Requires:       python-defusedxml >= 0.5.0
Requires:       python-dominate >= 2.2.0
Requires:       python-lxml >= 4.1.0
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
HTTPolice is a validator or linter for HTTP requests and responses.
It can spot bad header syntax, inappropriate status codes, and other potential
problems in your HTTP server or client.

%prep
%setup -q -n HTTPolice-%{version}
rm pytest.ini

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/httpolice
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# gh#vfaronov/httpolice#10
%pytest -k 'not test_from_file'

%post
%python_install_alternative httpolice

%postun
%python_uninstall_alternative httpolice

%files %{python_files}
%license LICENSE.txt
%doc CHANGELOG.rst README.rst
%python_alternative %{_bindir}/httpolice
%{python_sitelib}/httpolice
%{python_sitelib}/httpolice-%{version}*info

%changelog
* Tue May  6 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Mon Mar 22 2021 Matej Cepl <mcepl@suse.com>
- Skip test test_from_file to avoid filing test
  (gh#vfaronov/httpolice#10).
* Mon May 25 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Mar 10 2020 Tomáš Chvátal <tchvatal@suse.com>
- Do not run coverage report as it aint really needed
* Wed Jul 24 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.9.0
  * Basic checks for most of the headers defined by WHATWG Fetch,
    such as Access-Control-Allow-Origin.
  * Updated workarounds for HAR files exported from Chrome and Firefox.
  * See upstream changelog for more
* Tue May 14 2019 Ethan Apodaca <eapodaca@suse.com>
- Drop python2 support
- Remove py34-no-singledispatch.patch
- Replace brotlipy dependency with Brotli
- Remove dependancies that are not needed to build.
- Update to v0.8.0
  * Changes
    + Dropped Python 2 support. If you need it, use the older versions.
    + HTTPolice no longer requires six nor singledispatch.
    + HTTPolice now pulls in Google's Brotli instead of brotlipy,
    but this is merely a packaging change; it can work with either.
    + Notices 1299 and 1300 are no longer reported on Alt-Svc.
* Mon Feb 11 2019 John Vandenberg <jayvdb@gmail.com>
- Fix Python 3 tests
- Add py34-no-singledispatch.patch to remove unnecessary 'singledispatch'
  dependency, which is a backport from Python 3.4
- Update to v0.7.0
  * Changes
    + Reflecting changes in RFC 8187 and RFC 8259,
    notices 1253 (bad charset) and 1281 (bad encoding for JSON)
    are now reported for all encodings other than UTF-8, and
    notice 1255 (ISO-8859-1 in Content-Disposition) has been removed.
  * Added
    + Checks for quoted commas and semicolons that might confuse a naive parser
    (notices 1299 and 1300).
    + New checks for Link headers according to RFC 8288 (notices 1307,
    1308, and 1309).
    + Checks for immutable responses (notices 1301, 1302, and 1303).
    + Early hints are now recognized (due to their idiosyncratic semantics,
    they avoid many checks that are applied to all other responses).
    + Checks for the Accept-Post header (notice 1310).
    + Check for no Transfer-Encoding in response to HTTP/1.0 (notice 1306).
    + Check for 100 (Continue) before switching protocols (notice 1305).
    + Check that the sequence of responses to a request makes sense
    (notice 1304).
    + HAR files exported from Chrome and Insomnia are handled slightly better.
  * Fixed
    + Headers like Allow and Accept are now parsed more correctly
    (RFC Errata 5257).
    + gzip-encoded payloads are now decompressed more reliably.
    + When analyzing TCP streams, HTTPolice now uses a stricter heuristic
    for detecting HTTP/1.x streams, producing fewer spurious 1006/1009
    notices.
    + Notice 1291 (Preference-Applied needs Vary) is no longer reported
    on responses to POST.
- Use %%license
- Remove unnecessary build dependencies
- Add more minimum versions
* Thu Nov 16 2017 toddrme2178@gmail.com
- Initial version
